%global _dwz_low_mem_die_limit 0
Name: docker-engine
Version: %{_version}
Release: %{_release}%{?dist}
Summary: The open-source application container engine
Group: Tools/Docker

License: ASL 2.0
Source: %{name}.tar.gz

URL: https://dockerproject.org
Vendor: Docker
Packager: Oracle USA <ol-ovm-info_ww@oracle.com>

# docker builds in a checksum of dockerinit into docker,
# # so stripping the binaries breaks docker
%global __os_install_post %{_rpmconfigdir}/brp-compress
%global debug_package %{nil}

# is_systemd conditional
%if 0%{?fedora} >= 21 || 0%{?centos} >= 7 || 0%{?rhel} >= 7 || 0%{?suse_version} >= 1210
%global is_systemd 1
%endif

# required packages for build
# most are already in the container (see contrib/builder/rpm/generate.sh)
# only require systemd on those systems
%if 0%{?is_systemd}
%if 0%{?suse_version} >= 1210
BuildRequires: systemd-rpm-macros
%{?systemd_requires}
%else
BuildRequires: pkgconfig(systemd)
Requires: systemd-units
BuildRequires: pkgconfig(libsystemd-journal)
%endif
%else
Requires(post): chkconfig
Requires(preun): chkconfig
# This is for /sbin/service
Requires(preun): initscripts
%endif

# required packages on install
Requires: /bin/sh
Requires: iptables
%if !0%{?suse_version}
Requires: libcgroup
%else
Requires: libcgroup1
%endif
Requires: tar
Requires: xz
%if 0%{?fedora} >= 21 || 0%{?centos} >= 7 || 0%{?rhel} >= 7 || 0%{?oraclelinux} >= 7
# Resolves: rhbz#1165615
Requires: device-mapper-libs >= 1.02.90-1
%endif
%if 0%{?oraclelinux} >= 6
# Require Oracle Unbreakable Enterprise Kernel R4 and newer device-mapper
Requires: kernel-uek >= 4.1
Requires: device-mapper >= 1.02.90-2
%endif

# docker-selinux conditional
%if 0%{?fedora} >= 20 || 0%{?centos} >= 7 || 0%{?rhel} >= 7 || 0%{?oraclelinux} >= 7
%global with_selinux 1
%endif

%if 0%{?_experimental}
# yubico-piv-tool conditional
%if 0%{?fedora} >= 20 || 0%{?centos} >= 7 || 0%{?rhel} >= 7
Requires: yubico-piv-tool >= 1.1.0
%endif
%endif

# start if with_selinux
%if 0%{?with_selinux}
# Version of SELinux we were using
%if 0%{?fedora} == 20
%global selinux_policyver 3.12.1-197
%endif # fedora 20
%if 0%{?fedora} == 21
%global selinux_policyver 3.13.1-105
%endif # fedora 21
%if 0%{?fedora} >= 22
%global selinux_policyver 3.13.1-128
%endif # fedora 22
%if 0%{?centos} >= 7 || 0%{?rhel} >= 7 || 0%{?oraclelinux} >= 7
%global selinux_policyver 3.13.1-23
%endif # centos,oraclelinux 7
%endif # with_selinux

# RE: rhbz#1195804 - ensure min NVR for selinux-policy
%if 0%{?with_selinux}
Requires: selinux-policy >= %{selinux_policyver}
Requires(pre): %{name}-selinux >= %{epoch}:%{version}-%{release}
%endif # with_selinux

# conflicting packages
Conflicts: docker
Conflicts: docker-io
Conflicts: docker-engine-cs

%description
Docker is an open source project to build, ship and run any application as a
lightweight container.

Docker containers are both hardware-agnostic and platform-agnostic. This means
they can run anywhere, from your laptop to the largest EC2 compute instance and
everything in between - and they don't require you to use a particular
language, framework or packaging system. That makes them great building blocks
for deploying and scaling web apps, databases, and backend services without
depending on a particular stack or provider.

%prep
%if 0%{?centos} <= 6 || 0%{?oraclelinux} <=6
%setup -n %{name}
%else
%autosetup -n %{name}
%endif

%build
export DOCKER_GITCOMMIT=%{_gitcommit}
./hack/make.sh dynbinary
# ./man/md2man-all.sh runs outside the build container (if at all), since we don't have go-md2man here

%check
./bundles/%{_origversion}/dynbinary/docker -v

%install
# install binary
install -d $RPM_BUILD_ROOT/%{_bindir}
install -p -m 755 bundles/%{_origversion}/dynbinary/docker-%{_origversion} $RPM_BUILD_ROOT/%{_bindir}/docker

# install dockerinit
install -d $RPM_BUILD_ROOT/%{_libexecdir}/docker
install -p -m 755 bundles/%{_origversion}/dynbinary/dockerinit-%{_origversion} $RPM_BUILD_ROOT/%{_libexecdir}/docker/dockerinit

# install udev rules
install -d $RPM_BUILD_ROOT/%{_sysconfdir}/udev/rules.d
install -p -m 644 contrib/udev/80-docker.rules $RPM_BUILD_ROOT/%{_sysconfdir}/udev/rules.d/80-docker.rules

# add init scripts
install -d $RPM_BUILD_ROOT/etc/sysconfig
install -d $RPM_BUILD_ROOT/%{_initddir}


%if 0%{?is_systemd}
install -d $RPM_BUILD_ROOT/%{_unitdir}
install -p -m 644 contrib/init/systemd/docker.service $RPM_BUILD_ROOT/%{_unitdir}/docker.service
install -p -m 644 contrib/init/systemd/docker.socket $RPM_BUILD_ROOT/%{_unitdir}/docker.socket
%else
install -p -m 644 contrib/init/sysvinit-redhat/docker.sysconfig $RPM_BUILD_ROOT/etc/sysconfig/docker
install -p -m 755 contrib/init/sysvinit-redhat/docker $RPM_BUILD_ROOT/%{_initddir}/docker
%endif

# Restore /etc/sysconfig/docker-* configuration on Oracle Linux 7 via systemd drop-in file
%if 0%{?oraclelinux} >= 7
install -d $RPM_BUILD_ROOT/%{_sysconfdir}/systemd/system/docker.service.d
install -d $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig
install -p -m 644 contrib/builder/rpm/oraclelinux-7/docker-sysconfig.conf $RPM_BUILD_ROOT/%{_sysconfdir}/systemd/system/docker.service.d/docker-sysconfig.conf
install -p -m 644 contrib/builder/rpm/oraclelinux-7/docker.sysconfig $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/docker
install -p -m 644 contrib/builder/rpm/oraclelinux-7/docker-network.sysconfig $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/docker-network
install -p -m 644 contrib/builder/rpm/oraclelinux-7/docker-storage.sysconfig $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/docker-storage
%endif

# add bash, zsh, and fish completions
install -d $RPM_BUILD_ROOT/usr/share/bash-completion/completions
install -d $RPM_BUILD_ROOT/usr/share/zsh/vendor-completions
install -d $RPM_BUILD_ROOT/usr/share/fish/vendor_completions.d
install -p -m 644 contrib/completion/bash/docker $RPM_BUILD_ROOT/usr/share/bash-completion/completions/docker
install -p -m 644 contrib/completion/zsh/_docker $RPM_BUILD_ROOT/usr/share/zsh/vendor-completions/_docker
install -p -m 644 contrib/completion/fish/docker.fish $RPM_BUILD_ROOT/usr/share/fish/vendor_completions.d/docker.fish

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 man/man1/*.1 $RPM_BUILD_ROOT/%{_mandir}/man1
install -d %{buildroot}%{_mandir}/man5
install -p -m 644 man/man5/*.5 $RPM_BUILD_ROOT/%{_mandir}/man5

# add vimfiles
install -d $RPM_BUILD_ROOT/usr/share/vim/vimfiles/doc
install -d $RPM_BUILD_ROOT/usr/share/vim/vimfiles/ftdetect
install -d $RPM_BUILD_ROOT/usr/share/vim/vimfiles/syntax
install -p -m 644 contrib/syntax/vim/doc/dockerfile.txt $RPM_BUILD_ROOT/usr/share/vim/vimfiles/doc/dockerfile.txt
install -p -m 644 contrib/syntax/vim/ftdetect/dockerfile.vim $RPM_BUILD_ROOT/usr/share/vim/vimfiles/ftdetect/dockerfile.vim
install -p -m 644 contrib/syntax/vim/syntax/dockerfile.vim $RPM_BUILD_ROOT/usr/share/vim/vimfiles/syntax/dockerfile.vim

# add nano
install -d $RPM_BUILD_ROOT/usr/share/nano
install -p -m 644 contrib/syntax/nano/Dockerfile.nanorc $RPM_BUILD_ROOT/usr/share/nano/Dockerfile.nanorc

# list files owned by the package here
%files
%doc AUTHORS CHANGELOG.md CONTRIBUTING.md LICENSE MAINTAINERS NOTICE README.md
/%{_bindir}/docker
/%{_libexecdir}/docker/dockerinit
/%{_sysconfdir}/udev/rules.d/80-docker.rules
%if 0%{?is_systemd}
/%{_unitdir}/docker.service
/%{_unitdir}/docker.socket
%else
%config(noreplace,missingok) /etc/sysconfig/docker
/%{_initddir}/docker
%endif
%if 0%{?oraclelinux} >= 7
%{_sysconfdir}/systemd/system/docker.service.d/docker-sysconfig.conf
%config(noreplace) /%{_sysconfdir}/sysconfig/docker
%config(noreplace) /%{_sysconfdir}/sysconfig/docker-network
%config(noreplace) /%{_sysconfdir}/sysconfig/docker-storage
%endif
/usr/share/bash-completion/completions/docker
/usr/share/zsh/vendor-completions/_docker
/usr/share/fish/vendor_completions.d/docker.fish
%doc
/%{_mandir}/man1/*
/%{_mandir}/man5/*
/usr/share/vim/vimfiles/doc/dockerfile.txt
/usr/share/vim/vimfiles/ftdetect/dockerfile.vim
/usr/share/vim/vimfiles/syntax/dockerfile.vim
/usr/share/nano/Dockerfile.nanorc

%post
%if 0%{?is_systemd}
%systemd_post docker
%else
# This adds the proper /etc/rc*.d links for the script
/sbin/chkconfig --add docker
%endif
if ! getent group docker > /dev/null; then
    groupadd --system docker
fi

%preun
%if 0%{?is_systemd}
%systemd_preun docker
%else
if [ $1 -eq 0 ] ; then
    /sbin/service docker stop >/dev/null 2>&1
    /sbin/chkconfig --del docker
fi
%endif

%postun
%if 0%{?is_systemd}
%systemd_postun_with_restart docker
%else
if [ "$1" -ge "1" ] ; then
    /sbin/service docker condrestart >/dev/null 2>&1 || :
fi
%endif

%changelog

* Thu Apr 21 2016 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.10.3-1.0.2
- Docker-Engine networking breaks when upgrading to 1.10.3 [orabug 23141357]

* Fri Mar 11 2016 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.10.3-1.0.1
- Enable configuration of Docker daemon via sysconfig [orabug 21804877]
- Require UEK4 for docker 1.9 [orabug 22235639 22235645]

* Thu Mar 10 2016 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.10.3
- Fix Docker client exiting with an "Unrecognized input header" error [#20706](https://github.com/docker/docker/pull/20706)
- Fix Docker exiting if Exec is started with both AttachStdin and Detach [#20647](https://github.com/docker/docker/pull/20647)
- Fix a crash when pushing multiple images sharing the same layers to the same repository in parallel [#20831](https://github.com/docker/docker/pull/20831)
- Fix a panic when pushing images to a registry which uses a misconfigured token service [#21030](https://github.com/docker/docker/pull/21030)
- Fix issue preventing volume plugins to start when SELinux is enabled [#20834](https://github.com/docker/docker/pull/20834)
- Prevent Docker from exiting if a volume plugin returns a null response for Get requests [#20682](https://github.com/docker/docker/pull/20682)
- Fix plugin system leaking file descriptors if a plugin has an error [#20680](https://github.com/docker/docker/pull/20680)
- Fix linux32 emulation to fail during docker build [#20672](https://github.com/docker/docker/pull/20672)
- Fix Oracle XE 10g failing to start in a container [#20981](https://github.com/docker/docker/pull/20981)
- Fix user namespaces not working on Linux From Scratch [#20685](https://github.com/docker/docker/pull/20685)
- Fix issue preventing daemon to start if userns is enabled and the subuid or subgid files contain comments [#20725](https://github.com/docker/docker/pull/20725)

* Mon Feb 22 2016 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.10.2
- Prevent systemd from deleting containers' cgroups when its configuration is reloaded [#20518](https://github.com/docker/docker/pull/20518)
- Fix SELinux issues by disregarding --read-only when mounting /dev/mqueue [#20333](https://github.com/docker/docker/pull/20333)
- Fix chown permissions used during docker cp when userns is used [#20446](https://github.com/docker/docker/pull/20446)
- Fix configuration loading issue with all booleans defaulting to true [#20471](https://github.com/docker/docker/pull/20471)
- Fix occasional panic with docker logs -f [#20522](https://github.com/docker/docker/pull/20522)
- Keep layer reference if deletion failed to avoid a badly inconsistent state [#20513](https://github.com/docker/docker/pull/20513)
- Handle gracefully a corner case when canceling migration [#20372](https://github.com/docker/docker/pull/20372)
- Fix docker import on compressed data [#20367](https://github.com/docker/docker/pull/20367)
- Fix tar-split files corruption during migration that later cause docker push and docker save to fail [#20458](https://github.com/docker/docker/pull/20458)
- Fix daemon crash if embedded DNS is sent garbage [#20510](https://github.com/docker/docker/pull/20510)
- Fix issue with multiple volume references with same name [#20381](https://github.com/docker/docker/pull/20381)
- Fix potential cache corruption and delegation conflict issues [#20523](https://github.com/docker/docker/pull/20523)

* Thu Feb 11 2016 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.10.1
- Do not stop daemon on migration hard failure [#20156](https://github.com/docker/docker/pull/20156)
- Fix various issues with migration to content-addressable images [#20058](https://github.com/docker/docker/pull/20058)
- Fix ZFS permission bug with user namespaces [#20045](https://github.com/docker/docker/pull/20045)
- Do not leak /dev/mqueue from the host to all containers, keep it container-specific [#19876](https://github.com/docker/docker/pull/19876) [#20133](https://github.com/docker/docker/pull/20133)
- Fix docker ps --filter before=... to not show stopped containers without providing -a flag [#20135](https://github.com/docker/docker/pull/20135)
- Fix issue preventing docker events to work properly with authorization plugin [#20002](https://github.com/docker/docker/pull/20002)
- Add additional verifications and prevent from uploading invalid data to registries [#20164](https://github.com/docker/docker/pull/20164)
- Fix regression preventing uppercase characters in image reference hostname [#20175](https://github.com/docker/docker/pull/20175)
- Fix embedded DNS for user-defined networks in the presence of firewalld [#20060](https://github.com/docker/docker/pull/20060)
- Fix issue where removing a network during shutdown left Docker inoperable [#20181](https://github.com/docker/docker/issues/20181) [#20235](https://github.com/docker/docker/issues/20235)
- Embedded DNS is now able to return compressed results [#20181](https://github.com/docker/docker/issues/20181)
- Fix port-mapping issue with userland-proxy=false [#20181](https://github.com/docker/docker/issues/20181)
- Fix bug where tcp+tls protocol would be rejected [#20109](https://github.com/docker/docker/pull/20109)
- Fix issue whereby older volume drivers would not receive volume options [#19983](https://github.com/docker/docker/pull/19983)
- Remove TasksMax from Docker systemd service [#20167](https://github.com/docker/docker/pull/20167)

* Thu Feb 04 2016 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.10.0
- New docker update command that allows updating resource constraints on running containers [#15078](https://github.com/docker/docker/pull/15078)
- Add --tmpfs flag to docker run to create a tmpfs mount in a container [#13587](https://github.com/docker/docker/pull/13587)
- Add --format flag to docker images command [#17692](https://github.com/docker/docker/pull/17692)
- Allow to set daemon configuration in a file and hot-reload it with the SIGHUP signal [#18587](https://github.com/docker/docker/pull/18587)
- Updated docker events to include more meta-data and event types [#18888](https://github.com/docker/docker/pull/18888)
- Add --blkio-weight-device flag to docker run [#13959](https://github.com/docker/docker/pull/13959)
- Add --device-read-bps and --device-write-bps flags to docker run [#14466](https://github.com/docker/docker/pull/14466)
- Add --device-read-iops and --device-write-iops flags to docker run [#15879](https://github.com/docker/docker/pull/15879)
- Add --oom-score-adj flag to docker run [#16277](https://github.com/docker/docker/pull/16277)
- Add --detach-keys flag to attach, run, start and exec commands to override the default key sequence that detaches from a container  [#15666](https://github.com/docker/docker/pull/15666)
- Add --shm-size flag to run, create and build to set the size of /dev/shm [#16168](https://github.com/docker/docker/pull/16168)
- Show the number of running, stopped, and paused containers in docker info [#19249](https://github.com/docker/docker/pull/19249)
- Show the OSType and Architecture in docker info [#17478](https://github.com/docker/docker/pull/17478)
- Add --cgroup-parent flag on daemon to set cgroup parent for all containers [#19062](https://github.com/docker/docker/pull/19062)
- Add -L flag to docker cp to follow symlinks [#16613](https://github.com/docker/docker/pull/16613)
- New status=dead filter for docker ps [#17908](https://github.com/docker/docker/pull/17908)
- Change docker run exit codes to distinguish between runtime and application errors [#14012](https://github.com/docker/docker/pull/14012)
- Enhance docker events --since and --until to support nanoseconds and timezones [#17495](https://github.com/docker/docker/pull/17495)
- Add --all/-a flag to stats to include both running and stopped containers [#16742](https://github.com/docker/docker/pull/16742)
- Change the default cgroup-driver to cgroupfs [#17704](https://github.com/docker/docker/pull/17704)
- Emit a "tag" event when tagging an image with build -t [#17115](https://github.com/docker/docker/pull/17115)
- Best effort for linked containers' start order when starting the daemon [#18208](https://github.com/docker/docker/pull/18208)
- Add ability to add multiple tags on build [#15780](https://github.com/docker/docker/pull/15780)
- Permit OPTIONS request against any url, thus fixing issue with CORS [#19569](https://github.com/docker/docker/pull/19569)
- Fix the --quiet flag on docker build to actually be quiet [#17428](https://github.com/docker/docker/pull/17428)
- Fix docker images --filter dangling=false to now show all non-dangling images [#19326](https://github.com/docker/docker/pull/19326)
- Fix race condition causing autorestart turning off on restart [#17629](https://github.com/docker/docker/pull/17629)
- Recognize GPFS filesystems [#19216](https://github.com/docker/docker/pull/19216)
- Fix obscure bug preventing to start containers [#19751](https://github.com/docker/docker/pull/19751)
- Forbid exec during container restart [#19722](https://github.com/docker/docker/pull/19722)
- devicemapper: Increasing --storage-opt dm.basesize will now increase the base device size on daemon restart [#19123](https://github.com/docker/docker/pull/19123)
- Add --userns-remap flag to daemon to support user namespaces (previously in experimental) [#19187](https://github.com/docker/docker/pull/19187)
- Add support for custom seccomp profiles in --security-opt [#17989](https://github.com/docker/docker/pull/17989)
- Add default seccomp profile [#18780](https://github.com/docker/docker/pull/18780)
- Add --authorization-plugin flag to daemon to customize ACLs [#15365](https://github.com/docker/docker/pull/15365)
- Docker Content Trust now supports the ability to read and write user delegations [#18887](https://github.com/docker/docker/pull/18887)
- Allow SELinux to run in a container when using the BTRFS storage driver [#16452](https://github.com/docker/docker/pull/16452)
- Use content-addressable storage for images and layers [#17924](https://github.com/docker/docker/pull/17924)
- Add support for the new [manifest format ("schema2")](https://github.com/docker/distribution/blob/master/docs/spec/manifest-v2-2.md) [#18785](https://github.com/docker/docker/pull/18785)
- Lots of improvements for push and pull: performance++, retries on failed downloads, cancelling on client disconnect [#18353](https://github.com/docker/docker/pull/18353), [#18418](https://github.com/docker/docker/pull/18418), [#19109](https://github.com/docker/docker/pull/19109), [#18353](https://github.com/docker/docker/pull/18353)
- Limit v1 protocol fallbacks [#18590](https://github.com/docker/docker/pull/18590)
- Fix issue where docker could hang indefinitely waiting for a nonexistent process to pull an image [#19743](https://github.com/docker/docker/pull/19743)
- Use DNS-based discovery instead of /etc/hosts [#19198](https://github.com/docker/docker/pull/19198)
- Support for network-scoped alias using --net-alias on run and --alias on network connect [#19242](https://github.com/docker/docker/pull/19242)
- Add --ip and --ip6 on run and network connect to support custom IP addresses for a container in a network [#19001](https://github.com/docker/docker/pull/19001)
- Add --ipam-opt to network create for passing custom IPAM options [#17316](https://github.com/docker/docker/pull/17316)
- Add --internal flag to network create to restrict external access to and from the network [#19276](https://github.com/docker/docker/pull/19276)
- Add kv.path option to --cluster-store-opt [#19167](https://github.com/docker/docker/pull/19167)
- Add discovery.heartbeat and discovery.ttl options to --cluster-store-opt to configure discovery TTL and heartbeat timer [#18204](https://github.com/docker/docker/pull/18204)
- Add --format flag to network inspect [#17481](https://github.com/docker/docker/pull/17481)
- Add --link to network connect to provide a container-local alias [#19229](https://github.com/docker/docker/pull/19229)
- Support for Capability exchange with remote IPAM plugins [#18775](https://github.com/docker/docker/pull/18775)
- Add --force to network disconnect to force container to be disconnected from network [#19317](https://github.com/docker/docker/pull/19317)
- Support for multi-host networking using built-in overlay driver for all engine supported kernels: 3.10+ [#18775](https://github.com/docker/docker/pull/18775)
- --link is now supported on docker run for containers in user-defined network [#19229](https://github.com/docker/docker/pull/19229)
- Enhance docker network rm to allow removing multiple networks [#17489](https://github.com/docker/docker/pull/17489)
- Include container names in network inspect [#17615](https://github.com/docker/docker/pull/17615)
- Include auto-generated subnets for user-defined networks in network inspect [#17316](https://github.com/docker/docker/pull/17316)
- Add --filter flag to network ls to hide predefined networks [#17782](https://github.com/docker/docker/pull/17782)
- Add support for network connect/disconnect to stopped containers [#18906](https://github.com/docker/docker/pull/18906)
- Add network ID to container inspect [#19323](https://github.com/docker/docker/pull/19323)
- Fix MTU issue where Docker would not start with two or more default routes [#18108](https://github.com/docker/docker/pull/18108)
- Fix duplicate IP address for containers [#18106](https://github.com/docker/docker/pull/18106)
- Fix issue preventing sometimes docker from creating the bridge network [#19338](https://github.com/docker/docker/pull/19338)
- Do not substitute 127.0.0.1 name server when using --net=host [#19573](https://github.com/docker/docker/pull/19573)
- New logging driver for Splunk [#16488](https://github.com/docker/docker/pull/16488)
- Add support for syslog over TCP+TLS [#18998](https://github.com/docker/docker/pull/18998)
- Enhance docker logs --since and --until to support nanoseconds and time [#17495](https://github.com/docker/docker/pull/17495)
- Enhance AWS logs to auto-detect region [#16640](https://github.com/docker/docker/pull/16640)
- Add support to set the mount propagation mode for a volume [#17034](https://github.com/docker/docker/pull/17034)
- Add ls and inspect endpoints to volume plugin API [#16534](https://github.com/docker/docker/pull/16534)
- Fix data not being copied to named volumes [#19175](https://github.com/docker/docker/pull/19175)
- Fix issues preventing volume drivers from being containerized [#19500](https://github.com/docker/docker/pull/19500)
- Fix docker volumes ls --dangling=false to now show all non-dangling volumes [#19671](https://github.com/docker/docker/pull/19671)
- Do not remove named volumes on container removal [#19568](https://github.com/docker/docker/pull/19568)
- Allow external volume drivers to host anonymous volumes [#19190](https://github.com/docker/docker/pull/19190)
- Add support for ** in .dockerignore to wildcard multiple levels of directories [#17090](https://github.com/docker/docker/pull/17090)
- Fix handling of UTF-8 characters in Dockerfiles [#17055](https://github.com/docker/docker/pull/17055)
- Fix permissions problem when reading from STDIN [#19283](https://github.com/docker/docker/pull/19283)
- Add support for overriding the API version to use via an DOCKER_API_VERSION environment-variable [#15964](https://github.com/docker/docker/pull/15964)
- Fix a bug preventing Windows clients to log in to Docker Hub [#19891](https://github.com/docker/docker/pull/19891)
- systemd: Set TasksMax in addition to LimitNPROC in systemd service file [#19391](https://github.com/docker/docker/pull/19391)
- Remove LXC support. The LXC driver was deprecated in Docker 1.8, and has now been removed [#17700](https://github.com/docker/docker/pull/17700)
- Remove --exec-driver daemon flag, because it is no longer in use [#17700](https://github.com/docker/docker/pull/17700)
- Remove old deprecated single-dashed long CLI flags (such as -rm; use --rm instead) [#17724](https://github.com/docker/docker/pull/17724)
- Deprecate HostConfig at API container start [#17799](https://github.com/docker/docker/pull/17799)
- Deprecate docker packages for newly EOL'd Linux distributions: Fedora 21 and Ubuntu 15.04 (Vivid) [#18794](https://github.com/docker/docker/pull/18794), [#18809](https://github.com/docker/docker/pull/18809)
- Deprecate -f flag for docker tag [#18350](https://github.com/docker/docker/pull/18350)

* Sat Nov 21 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.9.1
- Do not prevent daemon from booting if images could not be restored (#17695)
- Force IPC mount to unmount on daemon shutdown/init (#17539)
- Turn IPC unmount errors into warnings (#17554)
- Fix docker stats performance regression (#17638)
- Clarify cryptic error message upon docker logs if --log-driver=none (#17767)
- Fix seldom panics (#17639, #17634, #17703)
- Fix opq whiteouts problems for files with dot prefix (#17819)
- devicemapper: try defaulting to xfs instead of ext4 for performance reasons (#17903, #17918)
- devicemapper: fix displayed fs in docker info (#17974)
- selinux: only relabel if user requested so with the z option (#17450, #17834)
- Do not make network calls when normalizing names (#18014)
- Fix docker login on windows (#17738)
- Fix bug with docker inspect output when not connected to daemon (#17715)
- Fix docker inspect -f {{.HostConfig.Dns}} somecontainer (#17680)
- Fix regression with symlink behavior in ADD/COPY (#17710)
- Allow passing a network ID as an argument for --net (#17558)
- Fix connect to host and prevent disconnect from host for host network (#17476)
- Fix --fixed-cidr issue when gateway ip falls in ip-range and ip-range is
- Restore deterministic IPv6 generation from MAC address on default bridge network (#17890)
- Allow port-mapping only for endpoints created on docker run (#17858)
- Fixed an endpoint delete issue with a possible stale sbox (#18102)
- Correct parent chain in v2 push when v1Compatibility files on the disk are inconsistent (#18047)

* Tue Nov 03 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.9.0
- docker stats now returns block IO metrics (#15005)
- docker stats now details network stats per interface (#15786)
- Add ancestor=<image> filter to docker ps --filter flag to filter
- Add label=<somelabel> filter to docker ps --filter to filter containers
- Add --kernel-memory flag to docker run (#14006)
- Add --message flag to docker import allowing to specify an optional
- Add --privileged flag to docker exec (#14113)
- Add --stop-signal flag to docker run allowing to replace the container
- Add a new unless-stopped restart policy (#15348)
- Inspecting an image now returns tags (#13185)
- Add container size information to docker inspect (#15796)
- Add RepoTags and RepoDigests field to /images/{name:.*}/json (#17275)
- Remove the deprecated /container/ps endpoint from the API (#15972)
- Send and document correct HTTP codes for /exec/<name>/start (#16250)
- Share shm and mqueue between containers sharing IPC namespace (#15862)
- Event stream now shows OOM status when --oom-kill-disable is set (#16235)
- Ensure special network files (/etc/hosts etc.) are read-only if bind-mounted
- Improve rmi performance (#16890)
- Do not update /etc/hosts for the default bridge network, except for links (#17325)
- Fix conflict with duplicate container names (#17389)
- Fix an issue with incorrect template execution in docker inspect (#17284)
- DEPRECATE -c short flag variant for --cpu-shares in docker run (#16271)
- Allow docker import to import from local files (#11907)
- Add a STOPSIGNAL Dockerfile instruction allowing to set a different
- Add an ARG Dockerfile instruction and a --build-arg flag to docker build
- Improve cache miss performance (#16890)
- devicemapper: Implement deferred deletion capability (#16381)
- docker network exits experimental and is part of standard release (#16645)
- New network top-level concept, with associated subcommands and API (#16645)
- Support for multiple isolated/micro-segmented networks (#16645)
- Built-in multihost networking using VXLAN based overlay driver (#14071)
- Support for third-party network plugins (#13424)
- Ability to dynamically connect containers to multiple networks (#16645)
- Support for user-defined IP address management via pluggable IPAM drivers (#16910)
- Add daemon flags --cluster-store and --cluster-advertise for built-in nodes discovery (#16229)
- Add --cluster-store-opt for setting up TLS settings (#16644)
- Add --dns-opt to the daemon (#16031)
- DEPRECATE following container NetworkSettings fields in API v1.21: EndpointID, Gateway,
- New top-level volume subcommand and API (#14242)
- Move API volume driver settings to host-specific config (#15798)
- Print an error message if volume name is not unique (#16009)
- Ensure volumes created from Dockerfiles always use the local volume driver
- DEPRECATE auto-creating missing host paths for bind mounts (#16349)
- Add awslogs logging driver for Amazon CloudWatch (#15495)
- Add generic tag log option to allow customizing container/image
- Implement the docker logs endpoint for the journald driver (#13707)
- DEPRECATE driver-specific log tags (e.g. syslog-tag, etc.) (#15384)
- docker search now works with partial names (#16509)
- Push optimization: avoid buffering to file (#15493)
- The daemon will display progress for images that were already being pulled
- Only permissions required for the current action being performed are requested (#)
- Renaming trust keys (and respective environment variables) from offline to
- DEPRECATE trust key environment variables
- Add SELinux profiles to the rpm package (#15832)
- Fix various issues with AppArmor profiles provided in the deb package
- Add AppArmor policy that prevents writing to /proc (#15571)

* Mon Oct 12 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.8.3
- Fix layer IDs lead to local graph poisoning (CVE-2014-8178)
- Fix manifest validation and parsing logic errors allow pull-by-digest validation bypass (CVE-2014-8179)
- Add --disable-legacy-registry to prevent a daemon from using a v1 registry

* Thu Sep 10 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.8.2
- Fixes rare edge case of handling GNU LongLink and LongName entries.
- Fix ^C on docker pull.
- Fix docker pull issues on client disconnection.
- Fix issue that caused the daemon to panic when loggers weren't configured properly.
- Fix goroutine leak pulling images from registry V2.
- Fix a bug mounting cgroups for docker daemons running inside docker containers.
- Initialize log configuration properly.
- Handle -q flag in docker ps properly when there is a default format.
- Fix several corner cases with netlink.
- Fix several issues with bash completion.

* Wed Aug 12 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.8.1
- Fix a bug where pushing multiple tags would result in invalid images

* Tue Aug 11 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.8.0
- Trusted pull, push and build, disabled by default
- Make tar layers deterministic between registries
- Don't allow deleting the image of running containers
- Check if a tag name to load is a valid digest
- Allow one character repository names
- Add a more accurate error description for invalid tag name
- Make build cache ignore mtime
- Add support for DOCKER_CONFIG/--config to specify config file dir
- Add --type flag  for docker inspect command
- Add formatting options to docker ps with --format
- Replace docker -d with new subcommand docker daemon
- Zsh completion updates and improvements
- Add some missing events to bash completion
- Support daemon urls with base paths in docker -H
- Validate status= filter to docker ps
- Display when a container is in --net=host in docker ps
- Extend docker inspect to export image metadata related to graph driver
- Restore --default-gateway{,-v6} daemon options
- Add missing unpublished ports in docker ps
- Allow duration strings in docker events as --since/--until
- Expose more mounts information in docker inspect
- Add new Fluentd logging driver
- Allow docker import to load from local files
- Add logging driver for GELF via UDP
- Allow to copy files from host to containers with docker cp
- Promote volume drivers from experimental to master
- Add rollover options to json-file log driver, and --log-driver-opts flag
- Add memory swappiness tuning options
- Remove cgroup read-only flag when privileged
- Make /proc, /sys, & /dev readonly for readonly containers
- Add cgroup bind mount by default
- Overlay: Export metadata for container and image in docker inspect
- Devicemapper: external device activation
- Devicemapper: Compare uuid of base device on startup
- Remove RC4 from the list of registry cipher suites
- Add syslog-facility option
- LXC execdriver compatibility with recent LXC versions
- Mark LXC execriver as deprecated (to be removed with the migration to runc)
- Separate plugin sockets and specs locations
- Allow TLS connections to plugins
- Add missing 'Names' field to /containers/json API output
- Make docker rmi of dangling images safe while pulling
- Devicemapper: Change default basesize to 100G
- Go Scheduler issue with sync.Mutex and gcc
- Fix issue where Search API endpoint would panic due to empty AuthConfig
- Set image canonical names correctly
- Check dockerinit only if lxc driver is used
- Fix ulimit usage of nproc
- Always attach STDIN if -i,--interactive is specified
- Show error messages when saving container state fails
- Fixed incorrect assumption on --bridge=none treated as disable network
- Check for invalid port specifications in host configuration
- Fix endpoint leave failure for --net=host mode
- Fix goroutine leak in the stats API if the container is not running
- Check for apparmor file before reading it
- Fix DOCKER_TLS_VERIFY being ignored
- Set umask to the default on startup
- Correct the message of pause and unpause a non-running container
- Adjust disallowed CpuShares in container creation
- ZFS: correctly apply selinux context
- Display empty string instead of <nil> when IP opt is nil
- docker kill returns error when container is not running
- Fix COPY/ADD quoted/json form
- Fix goroutine leak on logs -f with no output
- Remove panic in nat package on invalid hostport
- Fix container linking in Fedora 22
- Fix error caused using default gateways outside of the allocated range
- Format times in inspect command with a template as RFC3339Nano
- Make registry client to accept 2xx and 3xx http status responses as successful
- Fix race issue that caused the daemon to crash with certain layer downloads failed in a specific order.
- Fix error when the docker ps format was not valid.
- Remove redundant ip forward check.
- Fix issue trying to push images to repository mirrors.
- Fix error cleaning up network entrypoints when there is an initialization issue.

* Tue Jul 14 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.7.1
- Fix default user spawning exec process with docker exec
- Make --bridge=none not to configure the network bridge
- Publish networking stats properly
- Fix implicit devicemapper selection with static binaries
- Fix socket connections that hung intermittently
- Fix bridge interface creation on CentOS/RHEL 6.6
- Fix local dns lookups added to resolv.conf
- Fix copy command mounting volumes
- Fix read/write privileges in volumes mounted with --volumes-from
- Fix unmarshalling of Command and Entrypoint
- Set limit for minimum client version supported
- Validate port specification
- Return proper errors when attach/reattach fail
- Fix pulling private images
- Fix fallback between registry V2 and V1

* Tue Jun 16 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.7.0
- Experimental feature: support for out-of-process volume plugins
- The userland proxy can be disabled in favor of hairpin NAT using the daemon’s --userland-proxy=false flag
- The exec command supports the -u|--user flag to specify the new process owner
- Default gateway for containers can be specified daemon-wide using the --default-gateway and --default-gateway-v6 flags
- The CPU CFS (Completely Fair Scheduler) quota can be set in docker run using --cpu-quota
- Container block IO can be controlled in docker run using--blkio-weight
- ZFS support
- The docker logs command supports a --since argument
- UTS namespace can be shared with the host with docker run --uts=host
- Networking stack was entirely rewritten as part of the libnetwork effort
- Engine internals refactoring
- Volumes code was entirely rewritten to support the plugins effort
- Sending SIGUSR1 to a daemon will dump all goroutines stacks without exiting
- Support ${variable:-value} and ${variable:+value} syntax for environment variables
- Support resource management flags --cgroup-parent, --cpu-period, --cpu-quota, --cpuset-cpus, --cpuset-mems
- git context changes with branches and directories
- The .dockerignore file support exclusion rules
- Client support for v2 mirroring support for the official registry
- Firewalld is now supported and will automatically be used when available
- mounting --device recursively

* Wed May 13 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.6.2
- Revert change prohibiting mounting into /sys

* Thu May 07 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.6.1
- Fix read/write /proc paths (CVE-2015-3630)
- Prohibit VOLUME /proc and VOLUME / (CVE-2015-3631)
- Fix opening of file-descriptor 1 (CVE-2015-3627)
- Fix symlink traversal on container respawn allowing local privilege escalation (CVE-2015-3629)
- Prohibit mount of /sys
- Update AppArmor policy to not allow mounts

* Tue Apr 07 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.6.0
- Building images from an image ID
- Build containers with resource constraints, ie docker build --cpu-shares=100 --memory=1024m...
- commit --change to apply specified Dockerfile instructions while committing the image
- import --change to apply specified Dockerfile instructions while importing the image
- Builds no longer continue in the background when canceled with CTRL-C
- Windows Support
- Container and image Labels
- --cgroup-parent for specifying a parent cgroup to place container cgroup within
- Logging drivers, json-file, syslog, or none
- Pulling images by ID
- --ulimit to set the ulimit on a container
- --default-ulimit option on the daemon which applies to all created containers (and overwritten by --ulimit on run)

* Tue Feb 10 2015 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.5.0
- Dockerfile to use for a given docker build can be specified with the -f flag
- Dockerfile and .dockerignore files can be themselves excluded as part of the .dockerignore file, thus preventing modifications to these files invalidating ADD or COPY instructions cache
- ADD and COPY instructions accept relative paths
- Dockerfile FROM scratch instruction is now interpreted as a no-base specifier
- Improve performance when exposing a large number of ports
- Allow client-side only integration tests for Windows
- Include docker-py integration tests against Docker daemon as part of our test suites
- Support for the new version of the registry HTTP API
- Speed up docker push for images with a majority of already existing layers
- Fixed contacting a private registry through a proxy
- A new endpoint will stream live container resource metrics and can be accessed with the docker stats command
- Containers can be renamed using the new rename endpoint and the associated docker rename command
- Container inspect endpoint show the ID of exec commands running in this container
- Container inspect endpoint show the number of times Docker auto-restarted the container
- New types of event can be streamed by the events endpoint: ‘OOM’ (container died with out of memory), ‘exec_create’, and ‘exec_start'
- Fixed returned string fields which hold numeric characters incorrectly omitting surrounding double quotes
- Docker daemon has full IPv6 support
- The docker run command can take the --pid=host flag to use the host PID namespace, which makes it possible for example to debug host processes using containerized debugging tools
- The docker run command can take the --read-only flag to make the container’s root filesystem mounted as readonly, which can be used in combination with volumes to force a container’s processes to only write to locations that will be persisted
- Container total memory usage can be limited for docker run using the --memory-swap flag
- Major stability improvements for devicemapper storage driver
- Better integration with host system: containers will reflect changes to the host's /etc/resolv.conf file when restarted
- Better integration with host system: per-container iptable rules are moved to the DOCKER chain
- Fixed container exiting on out of memory to return an invalid exit code
- The HTTP_PROXY, HTTPS_PROXY, and NO_PROXY environment variables are properly taken into account by the client when connecting to the Docker daemon

* Mon Dec 15 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.4.1
- Fix issue with volumes-from and bind mounts not being honored after create

* Thu Dec 11 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.4.0
- Set key=value labels to the daemon (displayed in docker info), applied with
- Add support for ENV in Dockerfile of the form:
- New Overlayfs Storage Driver
- docker info now returns an ID and Name field
- Filter events by event name, container, or image
- docker cp now supports copying from container volumes
- Fixed docker tag, so it honors --force when overriding a tag for existing

* Thu Dec 11 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.3.3
- Fix path traversal vulnerability in processing of absolute symbolic links (CVE-2014-9356)
- Fix decompression of xz image archives, preventing privilege escalation (CVE-2014-9357)
- Validate image IDs (CVE-2014-9358)
- Fix an issue when image archives are being read slowly
- Fix a regression related to stdin redirection
- Fix a regression with docker cp when destination is the current directory

* Thu Nov 20 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.3.2
- Fix tar breakout vulnerability
- Extractions are now sandboxed chroot
- Security options are no longer committed to images
- Fix deadlock in docker ps -f exited=1
- Fix a bug when --volumes-from references a container that failed to start
- --insecure-registry now accepts CIDR notation such as 10.1.0.0/16
- Private registries whose IPs fall in the 127.0.0.0/8 range do no need the --insecure-registry flag
- Skip the experimental registry v2 API when mirroring is enabled

* Tue Oct 28 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.3.1
- Prevent fallback to SSL protocols < TLS 1.0 for client, daemon and registry
- Secure HTTPS connection to registries with certificate verification and without HTTP fallback unless --insecure-registry is specified
- Fix issue where volumes would not be shared
- Fix issue with --iptables=false not automatically setting --ip-masq=false
- Fix docker run output to non-TTY stdout
- Fix escaping $ for environment variables
- Fix issue with lowercase onbuild Dockerfile instruction
- Restrict environment variable expansion to ENV, ADD, COPY, WORKDIR, EXPOSE, VOLUME and USER

* Tue Oct 14 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.3.0
- Docker exec allows you to run additional processes inside existing containers
- Docker create gives you the ability to create a container via the CLI without executing a process
- --security-opts options to allow user to customize container labels and apparmor profiles
- Docker ps filters
- Wildcard support to COPY/ADD
- Move production URLs to get.docker.com from get.docker.io
- Allocate IP address on the bridge inside a valid CIDR
- Use drone.io for PR and CI testing
- Ability to setup an official registry mirror
- Ability to save multiple images with docker save

* Wed Aug 20 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.2.0
- Make /etc/hosts /etc/resolv.conf and /etc/hostname editable at runtime
- Auto-restart containers using policies
- Use /var/lib/docker/tmp for large temporary files
- --cap-add and --cap-drop to tweak what linux capability you want
- --device to use devices in containers
- docker search on private registries
- Add exited filter to docker ps --filter
- docker rm -f now kills instead of stop
- Support for IPv6 addresses in --dns flag
- Proxy instances in separate processes
- Small bug fix on UDP proxy

* Wed Jul 23 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.1.2
- Fix port allocation for existing containers
- Fix containers restart on daemon restart
- Fix /etc/init.d/docker issue on Debian

* Wed Jul 09 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.1.1
- Fix issue with ADD

* Thu Jul 03 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.1.0
- Add .dockerignore support
- Pause containers during docker commit
- Add --tail to docker logs
- Allow a tar file as context for docker build
- Fix issue with white-spaces and multi-lines in Dockerfiles
- Overall performance improvements
- Allow / as source of docker run -v
- Fix port allocation
- Fix bug in docker save
- Add links information to docker inspect
- Improve command line parsing for docker commit
- Improve status code for the start and stop endpoints

* Thu Jun 19 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.0.1
- Enhance security for the LXC driver
- Fix ONBUILD instruction passed to grandchildren
- Fix events subscription
- Fix /etc/hostname file with host networking
- Allow -h and --net=none
- Fix issue with hotplug devices in --privileged
- Fix artifacts with events
- Fix a panic with empty flags
- Fix docker cp on Mac OS X
- Fix compilation on Mac OS X
- Fix several races

* Mon Jun 09 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 1.0.0
- Production support

* Thu Jun 05 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.12.0
- 40+ various improvements to stability, performance and usability
- New COPY Dockerfile instruction to allow copying a local file from the context into the container without ever extracting if the file is a tar file
- Inherit file permissions from the host on ADD
- New pause and unpause commands to allow pausing and unpausing of containers using cgroup freezer
- The images command has a -f/--filter option to filter the list of images
- Add --force-rm to clean up after a failed build
- Standardize JSON keys in Remote API to CamelCase
- Pull from a docker run now assumes latest tag if not specified
- Enhance security on Linux capabilities and device nodes

* Wed May 07 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.11.1
- Fix push and pull to private registry

* Wed May 07 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.11.0
- SELinux support for mount and process labels
- Linked containers can be accessed by hostname
- Use the net --net flag to allow advanced network configuration such as host networking so that containers can use the host's network interfaces
- Add a ping endpoint to the Remote API to do healthchecks of your docker daemon
- Logs can now be returned with an optional timestamp
- Docker now works with registries that support SHA-512
- Multiple registry endpoints are supported to allow registry mirrors

* Tue Apr 08 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.10.0
- Fix printing multiple messages on a single line. Fixes broken output during builds.
- Follow symlinks inside container's root for ADD build instructions.
- Fix EXPOSE caching.
- Add the new options of docker ps to the documentation.
- Add the options of docker restart to the documentation.
- Update daemon docs and help messages for --iptables and --ip-forward.
- Updated apt-cacher-ng docs example.
- Remove duplicate description of --mtu from docs.
- Add missing -t and -v for docker images to the docs.
- Add fixes to the cli docs.
- Update libcontainer docs.
- Update images in docs to remove references to AUFS and LXC.
- Update the nodejs_web_app in the docs to use the new epel RPM address.
- Fix external link on security of containers.
- Update remote API docs.
- Add image size to history docs.
- Be explicit about binding to all interfaces in redis example.
- Document DisableNetwork flag in the 1.10 remote api.
- Document that --lxc-conf is lxc only.
- Add chef usage documentation.
- Add example for an image with multiple for docker load.
- Explain what docker run -a does in the docs.
- Add variable for DOCKER_LOGFILE to sysvinit and use append instead of overwrite in opening the logfile.
- Fix init script cgroup mounting workarounds to be more similar to cgroupfs-mount and thus work properly.
- Remove inotifywait hack from the upstart host-integration example because it's not necessary any more.
- Add check-config script to contrib.
- Fix fish shell completion.
- Clean up "go test" output from "make test" to be much more readable/scannable.
- Exclude more "definitely not unit tested Go source code" directories from hack/make/test.
- Generate md5 and sha256 hashes when building, and upload them via hack/release.sh.
- Include contributed completions in Ubuntu PPA.
- Add cli integration tests.
- Add tweaks to the hack scripts to make them simpler.
- Add TLS auth support for API.
- Move git clone from daemon to client.
- Fix content-type detection in docker cp.
- Split API into 2 go packages.
- Support hairpin NAT without going through Docker server.
- devicemapper: succeed immediately when removing non-existing devices.
- devicemapper: improve handling of devicemapper devices (add per device lock, increase sleep time and unlock while sleeping).
- devicemapper: increase timeout in waitClose to 10 seconds.
- devicemapper: ensure we shut down thin pool cleanly.
- devicemapper: pass info, rather than hash to activateDeviceIfNeeded, deactivateDevice, setInitialized, deleteDevice.
- devicemapper: avoid AB-BA deadlock.
- devicemapper: make shutdown better/faster.
- improve alpha sorting in mflag.
- Remove manual http cookie management because the cookiejar is being used.
- Use BSD raw mode on Darwin. Fixes nano, tmux and others.
- Add FreeBSD support for the client.
- Merge auth package into registry.
- Add deprecation warning for -t on docker pull.
- Remove goroutine leak on error.
- Update parseLxcInfo to comply with new lxc1.0 format.
- Fix attach exit on darwin.
- Improve deprecation message.
- Retry to retrieve the layer metadata up to 5 times for docker pull.
- Only unshare the mount namespace for execin.
- Merge existing config when committing.
- Disable daemon startup timeout.
- Fix issue #4681: add loopback interface when networking is disabled.
- Add failing test case for issue #4681.
- Send SIGTERM to child, instead of SIGKILL.
- Show the driver and the kernel version in docker info even when not in debug mode.
- Always symlink /dev/ptmx for libcontainer. This fixes console related problems.
- Fix issue caused by the absence of /etc/apparmor.d.
- Don't leave empty cidFile behind when failing to create the container.
- Mount cgroups automatically if they're not mounted already.
- Use mock for search tests.
- Update to double-dash everywhere.
- Move .dockerenv parsing to lxc driver.
- Move all bind-mounts in the container inside the namespace.
- Don't use separate bind mount for container.
- Always symlink /dev/ptmx for libcontainer.
- Don't kill by pid for other drivers.
- Add initial logging to libcontainer.
- Sort by port in docker ps.
- Move networking drivers into runtime top level package.
- Add --no-prune to docker rmi.
- Add time since exit in docker ps.
- graphdriver: add build tags.
- Prevent allocation of previously allocated ports & prevent improve port allocation.
- Add support for --since/--before in docker ps.
- Clean up container stop.
- Add support for configurable dns search domains.
- Add support for relative WORKDIR instructions.
- Add --output flag for docker save.
- Remove duplication of DNS entries in config merging.
- Add cpuset.cpus to cgroups and native driver options.
- Remove docker-ci.
- Promote btrfs. btrfs is no longer considered experimental.
- Add --input flag to docker load.
- Return error when existing bridge doesn't match IP address.
- Strip comments before parsing line continuations to avoid interpreting instructions as comments.
- Fix TestOnlyLoopbackExistsWhenUsingDisableNetworkOption to ignore "DOWN" interfaces.
- Add systemd implementation of cgroups and make containers show up as systemd units.
- Fix commit and import when no repository is specified.
- Remount /var/lib/docker as --private to fix scaling issue.
- Use the environment's proxy when pinging the remote registry.
- Reduce error level from harmless errors.
- Allow --volumes-from to be individual files.
- Fix expanding buffer in StdCopy.
- Set error regardless of attach or stdin. This fixes #3364.
- Add support for --env-file to load environment variables from files.
- Symlink /etc/mtab and /proc/mounts.
- Allow pushing a single tag.
- Shut down containers cleanly at shutdown and wait forever for the containers to shut down. This makes container shutdown on daemon shutdown work properly via SIGTERM.
- Don't throw error when starting an already running container.
- Fix dynamic port allocation limit.
- remove setupDev from libcontainer.
- Add API version to docker version.
- Return correct exit code when receiving signal and make SIGQUIT quit without cleanup.
- Fix --volumes-from mount failure.
- Allow non-privileged containers to create device nodes.
- Skip login tests because of external dependency on a hosted service.
- Deprecate docker images --tree and docker images --viz.
- Deprecate docker insert.
- Include base abstraction for apparmor. This fixes some apparmor related problems on Ubuntu 14.04.
- Add specific error message when hitting 401 over HTTP on push.
- Fix absolute volume check.
- Remove volumes-from from the config.
- Move DNS options to hostconfig.
- Update the apparmor profile for libcontainer.
- Add deprecation notice for docker commit -run.

* Mon Mar 24 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.9.1
- Fix printing multiple messages on a single line. Fixes broken output during builds.
- Fix external link on security of containers.
- Fix init script cgroup mounting workarounds to be more similar to cgroupfs-mount and thus work properly.
- Add variable for DOCKER_LOGFILE to sysvinit and use append instead of overwrite in opening the logfile.
- Generate md5 and sha256 hashes when building, and upload them via hack/release.sh.
- Fix content-type detection in docker cp.
- Use BSD raw mode on Darwin. Fixes nano, tmux and others.
- Only unshare the mount namespace for execin.
- Retry to retrieve the layer metadata up to 5 times for docker pull.
- Merge existing config when committing.
- Fix panic in monitor.
- Disable daemon startup timeout.
- Fix issue #4681: add loopback interface when networking is disabled.
- Add failing test case for issue #4681.
- Send SIGTERM to child, instead of SIGKILL.
- Show the driver and the kernel version in docker info even when not in debug mode.
- Always symlink /dev/ptmx for libcontainer. This fixes console related problems.
- Fix issue caused by the absence of /etc/apparmor.d.
- Don't leave empty cidFile behind when failing to create the container.
- Improve deprecation message.
- Fix attach exit on darwin.
- devicemapper: improve handling of devicemapper devices (add per device lock, increase sleep time, unlock while sleeping).
- devicemapper: succeed immediately when removing non-existing devices.
- devicemapper: increase timeout in waitClose to 10 seconds.
- Remove goroutine leak on error.
- Update parseLxcInfo to comply with new lxc1.0 format.

* Mon Mar 10 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.9.0
- Avoid extra mount/unmount during build. This fixes mount/unmount related errors during build.
- Add error to docker build --rm. This adds missing error handling.
- Forbid chained onbuild, onbuild from and  onbuild maintainer triggers.
- Make --rm the default for docker build.
- Download the docker client binary for Mac over https.
- Update the titles of the install instructions & descriptions.
- Add instructions for upgrading boot2docker.
- Add port forwarding example in OS X install docs.
- Attempt to disentangle repository and registry.
- Update docs to explain more about docker ps.
- Update sshd example to use a Dockerfile.
- Rework some examples, including the Python examples.
- Update docs to include instructions for a container's lifecycle.
- Update docs documentation to discuss the docs branch.
- Don't skip cert check for an example & use HTTPS.
- Bring back the memory and swap accounting section which was lost when the kernel page was removed.
- Explain DNS warnings and how to fix them on systems running and using a local nameserver.
- Add Tanglu support for mkimage-debootstrap.
- Add SteamOS support for mkimage-debootstrap.
- Get package coverage when running integration tests.
- Remove the Vagrantfile. This is being replaced with boot2docker.
- Fix tests on systems where aufs isn't available.
- Update packaging instructions and remove the dependency on lxc.
- Move code specific to the API to the api package.
- Fix header content type for the API. Makes all endpoints use proper content type.
- Fix registry auth & remove ping calls from CmdPush and CmdPull.
- Add newlines to the JSON stream functions.
- Do not ping the registry from the CLI. All requests to registries flow through the daemon.
- Check for nil information return in the lxc driver. This fixes panics with older lxc versions.
- Devicemapper: cleanups and fix for unmount. Fixes two problems which were causing unmount to fail intermittently.
- Devicemapper: remove directory when removing device. Directories don't get left behind when removing the device.
- Devicemapper: enable skip_block_zeroing. Improves performance by not zeroing blocks.
- Devicemapper: fix shutdown warnings. Fixes shutdown warnings concerning pool device removal.
- Ensure docker cp stream is closed properly. Fixes problems with files not being copied by docker cp.
- Stop making tcp:// default to 127.0.0.1:4243 and remove the default port for tcp.
- Fix --run in docker commit. This makes docker commit --run work again.
- Fix custom bridge related options. This makes custom bridges work again.
- Mount-bind the PTY as container console. This allows tmux/screen to run.
- Add the pure Go libcontainer library to make it possible to run containers using only features of the Linux kernel.
- Add native exec driver which uses libcontainer and make it the default exec driver.
- Add support for handling extended attributes in archives.
- Set the container MTU to be the same as the host MTU.
- Add simple sha256 checksums for layers to speed up docker push.
- Improve kernel version parsing.
- Allow flag grouping (docker run -it).
- Remove chroot exec driver.
- Fix divide by zero to fix panic.
- Rewrite docker rmi.
- Fix docker info with lxc 1.0.0.
- Fix fedora tty with apparmor.
- Don't always append env vars, replace defaults with vars from config.
- Fix a goroutine leak.
- Switch to Go 1.2.1.
- Fix unique constraint error checks.
- Handle symlinks for Docker's data directory and for TMPDIR.
- Add deprecation warnings for flags (-flag is deprecated in favor of --flag)
- Add apparmor profile for the native execution driver.
- Move system specific code from archive to pkg/system.
- Fix duplicate signal for docker run -i -t (issue #3336).
- Return correct process pid for lxc.
- Add a -G option to specify the group which unix sockets belong to.
- Add -f flag to docker rm to force removal of running containers.
- Kill ghost containers and restart all ghost containers when the docker daemon restarts.
- Add DOCKER_RAMDISK environment variable to make Docker work when the root is on a ramdisk.

* Tue Feb 18 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.8.1
- Avoid extra mount/unmount during build. This removes an unneeded mount/unmount operation which was causing problems with devicemapper
- Fix regression with ADD of tar files. This stops Docker from decompressing tarballs added via ADD from the local file system
- Add error to docker build --rm. This adds a missing error check to ensure failures to remove containers are detected and reported
- Update issue filing instructions
- Warn against the use of symlinks for Docker's storage folder
- Replace the Firefox example with an IceWeasel example
- Rewrite the PostgresSQL example using a Dockerfile and add more details to it
- Improve the OS X documentation
- Fix broken images API for version less than 1.7
- Use the right encoding for all API endpoints which return JSON
- Move remote api client to api/
- Queue calls to the API using generic socket wait
- Fix the use of custom settings for bridges and custom bridges
- Refactor the devicemapper code to avoid many mount/unmount race conditions and failures
- Remove two panics which could make Docker crash in some situations
- Don't ping registry from the CLI client
- Enable skip_block_zeroing for devicemapper. This stops devicemapper from always zeroing entire blocks
- Fix --run in docker commit. This makes docker commit store --run in the image configuration
- Remove directory when removing devicemapper device. This cleans up leftover mount directories
- Drop NET_ADMIN capability for non-privileged containers. Unprivileged containers can't change their network configuration
- Ensure docker cp stream is closed properly
- Avoid extra mount/unmount during container registration. This removes an unneeded mount/unmount operation which was causing problems with devicemapper
- Stop allowing tcp:// as a default tcp bin address which binds to 127.0.0.1:4243 and remove the default port
- Mount-bind the PTY as container console. This allows tmux and screen to run in a container
- Clean up archive closing. This fixes and improves archive handling
- Fix engine tests on systems where temp directories are symlinked
- Add test methods for save and load
- Avoid temporarily unmounting the container when restarting it. This fixes a race for devicemapper during restart
- Support submodules when building from a GitHub repository
- Quote volume path to allow spaces
- Fix remote tar ADD behavior. This fixes a regression which was causing Docker to extract tarballs

* Tue Feb 04 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.8.0
- Images and containers can be removed much faster
- Building an image from source with docker build is now much faster
- The Docker daemon starts and stops much faster
- The memory footprint of many common operations has been reduced, by streaming files instead of buffering them in memory, fixing memory leaks, and fixing various suboptimal memory allocations
- Several race conditions were fixed, making Docker more stable under very high concurrency load. This makes Docker more stable and less likely to crash and reduces the memory footprint of many common operations
- All packaging operations are now built on the Go language’s standard tar implementation, which is bundled with Docker itself. This makes packaging more portable across host distributions, and solves several issues caused by quirks and incompatibilities between different distributions of tar
- Docker can now create, remove and modify larger numbers of containers and images graciously thanks to more aggressive releasing of system resources. For example the storage driver API now allows Docker to do reference counting on mounts created by the drivers
- Many components have been separated into smaller sub-packages, each with a dedicated test suite. As a result the code is better-tested, more readable and easier to change
- The ADD instruction now supports caching, which avoids unnecessarily re-uploading the same source content again and again when it hasn’t changed
- The new ONBUILD instruction adds to your image a “trigger” instruction to be executed at a later time, when the image is used as the base for another build
- Docker now ships with an experimental storage driver which uses the BTRFS filesystem for copy-on-write
- Docker is officially supported on Mac OS X
- The Docker daemon supports systemd socket activation

* Tue Jan 14 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.7.6
- Do not follow symlink outside of build context
- Remount bind mounts when ro is specified
- Use https for fetching docker version
- Inline the test.docker.io fingerprint
- Add ca-certificates to packaging documentation

* Thu Jan 09 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.7.5
- Disable compression for build. More space usage but a much faster upload
- Fix ADD caching for certain paths
- Do not compress archive from git build
- Fix error in GROUP add example
- Make sure the GPG fingerprint is inline in the documentation
- Give more specific advice on setting up signing of commits for DCO
- Fix misspelled container names
- Do not add hostname when networking is disabled
- Return most recent image from the cache by date
- Return all errors from docker wait
- Add Content-Type Header "application/json" to GET /version and /info responses
- Update DCO to version 1.1
- Update Makefile to use "docker:GIT_BRANCH" as the generated image name
- Update Travis to check for new 1.1 DCO version

* Tue Jan 07 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.7.4
- Fix ADD caching issue with . prefixed path
- Fix docker build on devicemapper by reverting sparse file tar option
- Fix issue with file caching and prevent wrong cache hit
- Use same error handling while unmarshalling CMD and ENTRYPOINT
- Simplify and streamline Amazon Quickstart
- Install instructions use unprefixed Fedora image
- Update instructions for mtu flag for Docker on GCE
- Add Ubuntu Saucy to installation
- Fix for wrong version warning on master instead of latest
- Only get the image's rootfs when we need to calculate the image size
- Correctly handle unmapping UDP ports
- Make CopyFileWithTar use a pipe instead of a buffer to save memory on docker build
- Fix login message to say pull instead of push
- Fix "docker load" help by removing "SOURCE" prompt and mentioning STDIN
- Make blank -H option default to the same as no -H was sent
- Extract cgroups utilities to own submodule
- Add Travis CI configuration to validate DCO and gofmt requirements
- Add Developer Certificate of Origin Text
- Upgrade VBox Guest Additions
- Check standalone header when pinging a registry server

* Thu Jan 02 2014 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.7.3
- Update ADD to use the image cache, based on a hash of the added content
- Add error message for empty Dockerfile
- Fix outdated link to the "Introduction" on www.docker.io
- Update the docs to get wider when the screen does
- Add information about needing to install LXC when using raw binaries
- Update Fedora documentation to disentangle the docker and docker.io conflict
- Add a note about using the new -mtu flag in several GCE zones
- Add FrugalWare installation instructions
- Add a more complete example of docker run
- Fix API documentation for creating and starting Privileged containers
- Add missing "name" parameter documentation on "/containers/create"
- Add a mention of lxc-checkconfig as a way to check for some of the necessary kernel configuration
- Update the 1.8 API documentation with some additions that were added to the docs for 1.7
- Add missing libdevmapper dependency to the packagers documentation
- Update minimum Go requirement to a hard line at Go 1.2+
- Many minor improvements to the Vagrantfile
- Add ability to customize dockerinit search locations when compiling (to be used very sparingly only by packagers of platforms who require a nonstandard location)
- Add coverprofile generation reporting
- Add -a to our Go build flags, removing the need for recompiling the stdlib manually
- Update Dockerfile to be more canonical and have less spurious warnings during build
- Fix some miscellaneous docker pull progress bar display issues
- Migrate more miscellaneous packages under the "pkg" folder
- Update TextMate highlighting to automatically be enabled for files named "Dockerfile"
- Reorganize syntax highlighting files under a common "contrib/syntax" directory
- Update install.sh script (https://get.docker.io/) to not fail if busybox fails to download or run at the end of the Ubuntu/Debian installation
- Add support for container names in bash completion
- Add an official Docker client binary for Darwin (Mac OS X)
- Remove empty "Vendor" string and added "License" on deb package
- Add a stubbed version of "/etc/default/docker" in the deb package
- Update layer application to extract tars in place, avoiding file churn while handling whiteouts
- Fix permissiveness of mtime comparisons in tar handling (since GNU tar and Go tar do not yet support sub-second mtime precision)
- Reimplement docker top in pure Go to work more consistently, and even inside Docker-in-Docker (thus removing the shell injection vulnerability present in some versions of lxc-ps)
- Update -H unix:// to work similarly to -H tcp:// by inserting the default values for missing portions
- Fix more edge cases regarding dockerinit and deleted or replaced docker or dockerinit files
- Update container name validation to include '.'
- Fix use of a symlink or non-absolute path as the argument to -g to work as expected
- Update to handle external mounts outside of LXC, fixing many small mounting quirks and making future execution backends and other features simpler
- Update to use proper box-drawing characters everywhere in docker images -tree
- Move MTU setting from LXC configuration to directly use netlink
- Add -S option to external tar invocation for more efficient spare file handling
- Add arch/os info to User-Agent string, especially for registry requests
- Add -mtu option to Docker daemon for configuring MTU
- Fix docker build to exit with a non-zero exit code on error
- Add DOCKER_HOST environment variable to configure the client -H flag without specifying it manually for every invocation

* Mon Dec 16 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.7.2
- Validate container names on creation with standard regex
- Increase maximum image depth to 127 from 42
- Continue to move api endpoints to the job api
- Add -bip flag to allow specification of dynamic bridge IP via CIDR
- Allow bridge creation when ipv6 is not enabled on certain systems
- Set hostname and IP address from within dockerinit
- Drop capabilities from within dockerinit
- Fix volumes on host when symlink is present the image
- Prevent deletion of image if ANY container is depending on it even if the container is not running
- Update docker push to use new progress display
- Use os.Lstat to allow mounting unix sockets when inspecting volumes
- Adjust handling of inactive user login
- Add missing defines in devicemapper for older kernels
- Allow untag operations with no container validation
- Add auth config to docker build
- Add more information about Docker logging
- Add RHEL documentation
- Add a direct example for changing the CMD that is run in a container
- Update Arch installation documentation
- Add section on Trusted Builds
- Add Network documentation page
- Add new cover bundle for providing code coverage reporting
- Separate integration tests in bundles
- Make Tianon the hack maintainer
- Update mkimage-debootstrap with more tweaks for keeping images small
- Use https to get the install script
- Remove vendored dotcloud/tar now that Go 1.2 has been released

* Thu Dec 05 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.7.1
- Add @SvenDowideit as documentation maintainer
- Add links example
- Add documentation regarding ambassador pattern
- Add Google Cloud Platform docs
- Add dockerfile best practices
- Update doc for RHEL
- Update doc for registry
- Update Postgres examples
- Update doc for Ubuntu install
- Improve remote api doc
- Add hostconfig to docker inspect
- Implement docker log -f to stream logs
- Add env variable to disable kernel version warning
- Add -format to docker inspect
- Support bind-mount for files
- Fix bridge creation on RHEL
- Fix image size calculation
- Make sure iptables are called even if the bridge already exists
- Fix issue with stderr only attach
- Remove init layer when destroying a container
- Fix same port binding on different interfaces
- docker build now returns the correct exit code
- Fix docker port to display correct port
- docker build now check that the dockerfile exists client side
- docker attach now returns the correct exit code
- Remove the name entry when the container does not exist
- Improve progress bars, add ETA for downloads
- Simultaneous pulls now waits for the first to finish instead of failing
- Tag only the top-layer image when pushing to registry
- Fix issue with offline image transfer
- Fix issue preventing using ':' in password for registry
- Add pprof handler for debug
- Create a Makefile
- Use stdlib tar that now includes fix
- Improve make.sh test script
- Handle SIGQUIT on the daemon
- Disable verbose during tests
- Upgrade to go1.2 for official build
- Improve unit tests
- The test suite now runs all tests even if one fails
- Refactor C in Go (Devmapper)
- Fix OS X compilation

* Mon Nov 25 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.7.0
- Storage drivers: choose from aufs, device-mapper, or vfs.
- Standard Linux support: docker now runs on unmodified Linux kernels and all major distributions.
- Links: compose complex software stacks by connecting containers to each other.
- Container naming: organize your containers by giving them memorable names.
- Advanced port redirects: specify port redirects per interface, or keep sensitive ports private.
- Offline transfer: push and pull images to the filesystem without losing information.
- Quality: numerous bugfixes and small usability improvements. Significant increase in test coverage.

* Thu Nov 21 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.6.7
- Improve stability, fixes some race conditions
- Skip the volumes mounted when deleting the volumes of container.
- Fix layer size computation: handle hard links correctly
- Use the work Path for docker cp CONTAINER:PATH
- Fix tmp dir never cleanup
- Speedup docker ps
- More informative error message on name collisions
- Fix nameserver regex
- Always return long id's
- Fix container restart race condition
- Keep published ports on docker stop;docker start
- Fix container networking on Fedora
- Correctly express "any address" to iptables
- Fix network setup when reconnecting to ghost container
- Prevent deletion if image is used by a running container
- Lock around read operations in graph
- Return full ID on docker rmi
- Add -tree option to images
- Offline image transfer
- Exit with status 2 on usage error and display usage on stderr
- Do not forward SIGCHLD to container
- Use string timestamp for docker events -since
- Update to go 1.2rc5
- Add /etc/default/docker support to upstart

* Wed Nov 06 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.6.6
- Ensure container name on register
- Fix regression in /etc/hosts
- Add lock around write operations in graph
- Check if port is valid
- Fix restart runtime error with ghost container networking
- Add some more colors and animals to increase the pool of generated names
- Fix issues in docker inspect
- Escape apparmor confinement
- Set environment variables using a file.
- Prevent docker insert to erase something
- Prevent DNS server conflicts in CreateBridgeIface
- Validate bind mounts on the server side
- Use parent image config in docker build
- Fix regression in /etc/hosts
- Add -P flag to publish all exposed ports
- Add -notrunc and -q flags to docker history
- Fix docker commit, tag and import usage
- Add stars, trusted builds and library flags in docker search
- Fix docker logs with tty
- Make /events API send headers immediately
- Do not split last column docker top
- Add size to history
- Contrib: Desktop integration. Firefox usecase.
- Dockerfile: bump to go1.2rc3

* Tue Oct 29 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.6.5
- Containers can now be named
- Containers can now be linked together for service discovery
- 'run -a', 'start -a' and 'attach' can forward signals to the container for better integration with process supervisors
- Automatically start crashed containers after a reboot
- Expose IP, port, and proto as separate environment vars for container links
- Allow ports to be published to specific ips
- Prohibit inter-container communication by default
- Ignore ErrClosedPipe for stdin in Container.Attach
- Remove unused field kernelVersion
- Fix issue when mounting subdirectories of /mnt in container
- Fix untag during removal of images
- Check return value of syscall.Chdir when changing working directory inside dockerinit
- Only pass stdin to hijack when needed to avoid closed pipe errors
- Use less reflection in command-line method invocation
- Monitor the tty size after starting the container, not prior
- Remove useless os.Exit() calls after log.Fatal
- Add initial init scripts library and a safer Ubuntu packaging script that works for Debian
- Add -p option to invoke debootstrap with http_proxy
- Update install.sh with $sh_c to get sudo/su for modprobe
- Update all the mkimage scripts to use --numeric-owner as a tar argument
- Update hack/release.sh process to automatically invoke hack/make.sh and bail on build and test issues
- Documentation: Fix the flags for nc in example
- Testing: Remove warnings and prevent mount issues
- Testing: Change logic for tty resize to avoid warning in tests
- Builder: Fix race condition in docker build with verbose output
- Registry: Fix content-type for PushImageJSONIndex method
- Contrib: Improve helper tools to generate debian and Arch linux server images

* Wed Oct 16 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.6.4
- Add cleanup of container when Start() fails
- Add better comments to utils/stdcopy.go
- Add utils.Errorf for error logging
- Add -rm to docker run for removing a container on exit
- Remove error messages which are not actually errors
- Fix docker rm with volumes
- Fix some error cases where a HTTP body might not be closed
- Fix panic with wrong dockercfg file
- Fix the attach behavior with -i
- Record termination time in state.
- Use empty string so TempDir uses the OS's temp dir automatically
- Make sure to close the network allocators
- Autorestart containers by default
- Bump vendor kr/pty to commit 3b1f6487b (syscall.O_NOCTTY)
- lxc: Allow set_file_cap capability in container
- Move run -rm to the cli only
- Split stdout stderr
- Always create a new session for the container
- Add aggregated docker-ci email report
- Add cleanup to remove leftover containers
- Add nightly release to docker-ci
- Add more tests around auth.ResolveAuthConfig
- Remove a few errors in tests
- Catch errClosing error when TCP and UDP proxies are terminated
- Only run certain tests with TESTFLAGS='-run TestName' make.sh
- Prevent docker-ci to test closing PRs
- Replace panic by log.Fatal in tests
- Increase TestRunDetach timeout
- Add initial draft of the Docker infrastructure doc
- Add devenvironment link to CONTRIBUTING.md
- Add apt-get install curl to Ubuntu docs
- Add explanation for export restrictions
- Add .dockercfg doc
- Remove Gentoo install notes about #1422 workaround
- Fix help text for -v option
- Fix Ping endpoint documentation
- Fix parameter names in docs for ADD command
- Fix ironic typo in changelog
- Various command fixes in postgres example
- Document how to edit and release docs
- Minor updates to postgresql_service.rst
- Clarify LGTM process to contributors
- Corrected error in the package name
- Document what vagrant up is actually doing
- improve doc search results
- Cleanup whitespace in API 1.5 docs
- use angle brackets in MAINTAINER example email
- Update archlinux.rst
- Changes to a new style for the docs. Includes version switcher.
- Formatting, add information about multiline json
- Improve registry and index REST API documentation
- Replace deprecated upgrading reference to docker-latest.tgz, which hasn't been updated since 0.5.3
- Update Gentoo installation documentation now that we're in the portage tree proper
- Cleanup and reorganize docs and tooling for contributors and maintainers
- Minor spelling correction of protocoll -> protocol
- Add vim syntax highlighting for Dockerfiles from @honza
- Add mkimage-arch.sh
- Reorganize contributed completion scripts to add zsh completion
- Add vagrant user to the docker group
- Add proper bash completion for "docker push"
- Add xz utils as a runtime dep
- Add cleanup/refactor portion of #2010 for hack and Dockerfile updates
- Add contrib/mkimage-centos.sh back (from #1621), and associated documentation link
- Add several of the small make.sh fixes from #1920, and make the output more consistent and contributor-friendly
- Add @tianon to hack/MAINTAINERS
- Improve network performance for VirtualBox
- Revamp install.sh to be usable by more people, and to use official install methods whenever possible (apt repo, portage tree, etc.)
- Fix contrib/mkimage-debian.sh apt caching prevention
- Add Dockerfile.tmLanguage to contrib
- Configured FPM to make /etc/init/docker.conf a config file
- Enable SSH Agent forwarding in Vagrant VM
- Several small tweaks/fixes for contrib/mkimage-debian.sh
- Builder: Abort build if mergeConfig returns an error and fix duplicate error message
- Packaging: Remove deprecated packaging directory
- Registry: Use correct auth config when logging in.
- Registry: Fix the error message so it is the same as the regex

* Mon Sep 23 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.6.3
- Add 'docker' group on install for ubuntu package
- Update tar vendor dependency
- Download apt key over HTTPS
- Only copy and change permissions on non-bindmount volumes
- Allow multiple volumes-from
- Fix HTTP imports from STDIN
- Update section on extracting the docker binary after build
- Update development environment docs for new build process
- Remove 'base' image from documentation
- Client: Fix detach issue
- Registry: Update regular expression to match index

* Tue Sep 17 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.6.2
- Add domainname support
- Implement image filtering with path.Match
- Remove unnecessary warnings
- Remove os/user dependency
- Only mount the hostname file when the config exists
- Handle signals within the docker login command
- UID and GID are now also applied to volumes
- docker start set error code upon error
- docker run set the same error code as the process started
- Add -rm option in order to remove intermediate containers
- Allow multiline for the RUN instruction
- Implement login with private registry
- Fix push issues
- Hack: Vendor all dependencies
- Remote API: Bump to v1.5
- Packaging: Break down hack/make.sh into small scripts, one per 'bundle': test, binary, ubuntu etc.
- Documentation: General improvements

* Fri Aug 23 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.6.1
- Pass "meta" headers in API calls to the registry
- Use correct upstart script with new build tool
- Use libffi-dev, dont build it from sources
- Remove duplicate mercurial install command

* Thu Aug 22 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.6.0
- Add lxc-conf flag to allow custom lxc options
- Add an option to set the working directory
- Add Image name to LogEvent tests
- Add -privileged flag and relevant tests, docs, and examples
- Add websocket support to /container/<name>/attach/ws
- Add warning when net.ipv4.ip_forwarding = 0
- Add hostname to environment
- Add last stable version in docker version
- Fix race conditions in parallel pull
- Fix Graph ByParent() to generate list of child images per parent image.
- Fix typo: fmt.Sprint -> fmt.Sprintf
- Fix small \n error un docker build
- Fix to "Inject dockerinit at /.dockerinit"
- Fix #910. print user name to docker info output
- Use Go 1.1.2 for dockerbuilder
- Use ranged for loop on channels
- Use utils.ParseRepositoryTag instead of strings.Split(name, ":") in server.ImageDelete
- Improve CMD, ENTRYPOINT, and attach docs.
- Improve connect message with socket error
- Load authConfig only when needed and fix useless WARNING
- Show tag used when image is missing
- Apply volumes-from before creating volumes
- Make docker run handle SIGINT/SIGTERM
- Prevent crash when .dockercfg not readable
- Install script should be fetched over https, not http.
- API, issue 1471: Use groups for socket permissions
- Correctly detect IPv4 forwarding
- Mount /dev/shm as a tmpfs
- Switch from http to https for get.docker.io
- Let userland proxy handle container-bound traffic
- Update the Docker CLI to specify a value for the "Host" header.
- Change network range to avoid conflict with EC2 DNS
- Reduce connect and read timeout when pinging the registry
- Parallel pull
- Handle ip route showing mask-less IP addresses
- Allow ENTRYPOINT without CMD
- Always consider localhost as a domain name when parsing the FQN repos name
- Refactor checksum
- Add MongoDB image example
- Add instructions for creating and using the docker group
- Add sudo to examples and installation to documentation
- Add ufw doc
- Add a reference to ps -a
- Add information about Dockers high level tools over LXC.
- Fix typo in docs for docker run -dns
- Fix a typo in the ubuntu installation guide
- Fix to docs regarding adding docker groups
- Update default -H docs
- Update readme with dependencies for building
- Update amazon.rst to explain that Vagrant is not necessary for running Docker on ec2
- PostgreSQL service example in documentation
- Suggest installing linux-headers by default.
- Change the twitter handle
- Clarify Amazon EC2 installation
- 'Base' image is deprecated and should no longer be referenced in the docs.
- Move note about officially supported kernel
- Solved the logo being squished in Safari
- Add USER instruction do Dockerfile
- Add workdir support for the Buildfile
- Add no cache for docker build
- Fix docker build and docker events output
- Only count known instructions as build steps
- Make sure ENV instruction within build perform a commit each time
- Forbid certain paths within docker build ADD
- Repository name (and optionally a tag) in build usage
- Make sure ADD will create everything in 0755
- Sort Images by most recent creation date.
- Reworking opaque requests in registry module
- Add image name in /events
- Use mime pkg to parse Content-Type
- 650 http utils and user agent field
- Bash Completion: Limit commands to containers of a relevant state
- Add docker dependencies coverage testing into docker-ci
- Docker-brew 0.5.2 support and memory footprint reduction
- Add new docker dependencies into docker-ci
- Revert "docker.upstart: avoid spawning a sh process"
- Docker-brew and Docker standard library
- Release docker with docker
- Fix the upstart script generated by get.docker.io
- Enabled the docs to generate manpages.
- Revert Bind daemon to 0.0.0.0 in Vagrant.
- Improve auth push
- Registry unit tests + mock registry
- Improve TestKillDifferentUser to prevent timeout on buildbot
- Fix typo in TestBindMounts (runContainer called without image)
- Improve TestGetContainersTop so it does not rely on sleep
- Relax the lo interface test to allow iface index != 1
- Add registry functional test to docker-ci
- Add some tests in server and utils
- Contrib: bash completion script
- Client: Add docker cp command and copy api endpoint to copy container files/folders to the host
- Dont read from stdout when only attached to stdin

* Tue Aug 13 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.5.3
- Use docker group for socket permissions
- Spawn shell within upstart script
- Handle ip route showing mask-less IP addresses
- Add hostname to environment
- Make sure ENV instruction within build perform a commit each time

* Thu Aug 08 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.5.2
- Builder: Forbid certain paths within docker build ADD
- Runtime: Change network range to avoid conflict with EC2 DNS
- API: Change daemon to listen on unix socket by default

* Tue Jul 30 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.5.1
- Add ps args to docker top
- Add support for container ID files (pidfile like)
- Add container=lxc in default env
- Support networkless containers with docker run -n and docker -d -b=none
- Stdout/stderr logs are now stored in the same file as JSON
- Allocate a /16 IP range by default, with fallback to /24. Try 12 ranges instead of 3.
- Change .dockercfg format to json and support multiple auth remote
- Do not override volumes from config
- Fix issue with EXPOSE override
- Docker client now sets useragent (RFC 2616)
- Add /events endpoint
- ADD command now understands URLs
- CmdAdd and CmdEnv now respect Dockerfile-set ENV variables
- Create directories with 755 instead of 700 within ADD instruction
- Simplify unit tests with helpers
- Improve docker.upstart event
- Add coverage testing into docker-ci

* Wed Jul 17 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.5.0
- List all processes running inside a container with 'docker top'
- Host directories can be mounted as volumes with 'docker run -v'
- Containers can expose public UDP ports (eg, '-p 123/udp')
- Optionally specify an exact public port (eg. '-p 80:4500')
- 'docker login' supports additional options
- Dont save a containers hostname when committing an image.
- New image naming scheme inspired by Go packaging convention allows arbitrary combinations of registries
- Fix issues when uploading images to a private registry
- ENTRYPOINT instruction sets a default binary entry point to a container
- VOLUME instruction marks a part of the container as persistent data
- 'docker build' displays the full output of a build by default

* Mon Jul 01 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.4.8
- Builder: New build operation ENTRYPOINT adds an executable entry point to the container.  - Runtime: Fix a bug which caused 'docker run -d' to no longer print the container ID.
- Tests: Fix issues in the test suite

* Fri Jun 28 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.4.7
- The progress bar updates faster when downloading and uploading large files
- Fix a bug in the optional unix socket transport
- Improve detection of kernel version
- Host directories can be mounted as volumes with 'docker run -b'
- fix an issue when only attaching to stdin
- Use 'tar --numeric-owner' to avoid uid mismatch across multiple hosts
- Improve test suite and dev environment
- Remove dependency on unit tests on 'os/user'
- Registry: easier push/pull to a custom registry
- Documentation: add terminology section

* Sat Jun 22 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.4.6
- Runtime: fix a bug which caused creation of empty images (and volumes) to crash.

* Fri Jun 21 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.4.5
- Builder: 'docker build git://URL' fetches and builds a remote git repository
- Runtime: 'docker ps -s' optionally prints container size
- Tests: improved and simplified
- Runtime: fix a regression introduced in 0.4.3 which caused the logs command to fail.
- Builder: fix a regression when using ADD with single regular file.

* Wed Jun 19 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.4.4
- Builder: fix a regression introduced in 0.4.3 which caused builds to fail on new clients.

* Wed Jun 19 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.4.3
- ADD of a local file will detect tar archives and unpack them
- ADD improvements: use tar for copy + automatically unpack local archives
- ADD uses tar/untar for copies instead of calling 'cp -ar'
- Fix the behavior of ADD to be (mostly) reverse-compatible, predictable and well-documented.
- Fix a bug which caused builds to fail if ADD was the first command
- Nicer output for 'docker build'
- Remove bsdtar dependency
- Add unix socket and multiple -H support
- Prevent rm of running containers
- Use go1.1 cookiejar
- Fix issue detaching from running TTY container
- Forbid parallel push/pull for a single image/repo. Fixes #311
- Fix race condition within Run command when attaching.
- HumanReadable ProgressBar sizes in pull
- Fix docker versions git commit output
- Send all tags on History API call
- Add tag lookup to history command. Fixes #882
- Fix missing command in irc bouncer example

* Mon Jun 17 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.4.2
- Packaging: Bumped version to work around an Ubuntu bug

* Mon Jun 17 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.4.1
- Add flag to enable cross domain requests
- Add images and containers sizes in docker ps and docker images
- Configure dns configuration host-wide with 'docker -d -dns'
- Detect faulty DNS configuration and replace it with a public default
- Allow docker run <name>:<id>
- You can now specify public port (ex: -p 80:4500)
- Improve image removal to garbage-collect unreferenced parents
- Allow multiple params in inspect
- Print the container id before the hijack in docker run
- Add regexp check on repos name
- Move auth to the client
- Remove login check on pull
- Vagrantfile: Add the rest api port to vagrantfiles port_forward
- Upgrade to Go 1.1
- Builder: dont ignore last line in Dockerfile when it doesnt end with \n

* Mon Jun 03 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.4.0
- Introducing Builder
- 'docker build' builds a container, layer by layer, from a source repository containing a Dockerfile
- Introducing Remote API
- control Docker programmatically using a simple HTTP/json API
- Various reliability and usability improvements

* Thu May 30 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.3.4
- 'docker build' builds a container, layer by layer, from a source repository containing a Dockerfile
- 'docker build -t FOO' applies the tag FOO to the newly built container.
- Interactive TTYs correctly handle window resize
- Fix how configuration is merged between layers
- Split stdout and stderr on 'docker run'
- Optionally listen on a different IP and port (use at your own risk)
- Improve install instructions.

* Thu May 23 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.3.3
- Registry: Fix push regression
- Various bugfixes

* Thu May 09 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.3.2
- Improve the checksum process
- Use the size to have a good progress bar while pushing
- Use the actual archive if it exists in order to speed up the push
- Fix error 400 on push
- Store the actual archive on commit

* Wed May 08 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.3.1
- Implement the autorun capability within docker builder
- Add caching to docker builder
- Add support for docker builder with native API as top level command
- Implement ENV within docker builder
- Check the command existence prior create and add Unit tests for the case
- use any whitespaces instead of tabs
- Add go version to debug infos
- Kernel version - dont show the dash if flavor is empty
- Add docker search top level command in order to search a repository
- Fix pull for official images with specific tag
- Fix issue when login in with a different user and trying to push
- Improve checksum - async calculation
- Output graph of images to dot (graphviz)
- Fix ByParent function
- New introduction and high-level overview
- Add the documentation for docker builder
- CSS fix for docker documentation to make REST API docs look better.
- Fix CouchDB example page header mistake
- Fix README formatting
- Update www.docker.io website.
- Website: new high-level overview
- Makefile: Swap "go get" for "go get -d", especially to compile on go1.1rc
- Packaging: packaging ubuntu; issue #510: Use goland-stable PPA package to build docker

* Mon May 06 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.3.0
- Fix the command existence check
- strings.Split may return an empty string on no match
- Fix an index out of range crash if cgroup memory is not
- Various improvements
- New example: sharing data between 2 couchdb databases
- Vagrant: Use only one deb line in /etc/apt
- Registry: Implement the new registry

* Fri May 03 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.2.2
- Support for data volumes ('docker run -v=PATH')
- Share data volumes between containers ('docker run -volumes-from')
- Improve documentation
- Upgrade to Go 1.0.3
- Various upgrades to the dev environment for contributors

* Wed May 01 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.2.1
- 'docker commit -run' bundles a layer with default runtime options: command, ports etc.
- Improve install process on Vagrant
- New Dockerfile operation: "maintainer"
- New Dockerfile operation: "expose"
- New Dockerfile operation: "cmd"
- Contrib script to build a Debian base layer
- 'docker -d -r': restart crashed containers at daemon startup
- Runtime: improve test coverage

* Tue Apr 23 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.2.0
- Runtime: ghost containers can be killed and waited for
- Documentation: update install instructions
- Packaging: fix Vagrantfile
- Development: automate releasing binaries and ubuntu packages
- Add a changelog
- Various bugfixes

* Mon Apr 22 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.1.8
- Dynamically detect cgroup capabilities
- Issue stability warning on kernels <3.8
- 'docker push' buffers on disk instead of memory
- Fix 'docker diff' for removed files
- Fix 'docker stop' for ghost containers
- Fix handling of pidfile
- Various bugfixes and stability improvements

* Thu Apr 18 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.1.7
- Container ports are available on localhost
- 'docker ps' shows allocated TCP ports
- Contributors can run 'make hack' to start a continuous integration VM
- Streamline ubuntu packaging & uploading
- Various bugfixes and stability improvements

* Wed Apr 17 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.1.6
- Record the author an image with 'docker commit -author'

* Wed Apr 17 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.1.5
- Disable standalone mode
- Use a custom DNS resolver with 'docker -d -dns'
- Detect ghost containers
- Improve diagnosis of missing system capabilities
- Allow disabling memory limits at compile time
- Add debian packaging
- Documentation: installing on Arch Linux
- Documentation: running Redis on docker
- Fix lxc 0.9 compatibility
- Automatically load aufs module
- Various bugfixes and stability improvements

* Tue Apr 09 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.1.4
- Full support for TTY emulation
- Detach from a TTY session with the escape sequence C-p C-q
- Various bugfixes and stability improvements
- Minor UI improvements
- Automatically create our own bridge interface 'docker0'

* Thu Apr 04 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.1.3
- Choose TCP frontend port with '-p :PORT'
- Layer format is versioned
- Major reliability improvements to the process manager
- Various bugfixes and stability improvements

* Wed Apr 03 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.1.2
- Set container hostname with 'docker run -h'
- Selective attach at run with 'docker run -a [stdin[,stdout[,stderr]]]'
- Various bugfixes and stability improvements
- UI polish
- Progress bar on push/pull
- Use XZ compression by default
- Make IP allocator lazy

* Sun Mar 31 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.1.1
- Display shorthand IDs for convenience
- Stabilize process management
- Layers can include a commit message
- Simplified 'docker attach'
- Fix support for re-attaching
- Various bugfixes and stability improvements
- Auto-download at run
- Auto-login on push
- Beefed up documentation

* Sat Mar 23 2013 Oracle USA <ol-ovm-info_ww@oracle.com> - 0.1.0
- Implement registry in order to push/pull images
- TCP port allocation
- Fix termcaps on Linux
- Add documentation
- Add Vagrant support with Vagrantfile
- Add unit tests
- Add repository/tags to ease image management
- Improve the layer implementation
